/*
 *  upkg: tool for manipulating Unreal Tournament packages.
 *  Copyright © 2009-2011 Nick Bowler
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <glib-object.h>
#include <uobject/loadable.h>

GType u_object_loadable_get_type(void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (UObjectLoadable),
			NULL,
			NULL,
		};

		type = g_type_register_static(G_TYPE_INTERFACE,
			"UObjectLoadable", &info, 0);
	}
	return type;
}

int u_object_load(GObject *obj)
{
	g_return_val_if_fail(U_OBJECT_IS_LOADABLE(obj), -1);
	return U_OBJECT_LOADABLE_GET_INTERFACE(obj)->load(obj);
}

void u_object_unload(GObject *obj)
{
	g_return_if_fail(U_OBJECT_IS_LOADABLE(obj));
	U_OBJECT_LOADABLE_GET_INTERFACE(obj)->unload(obj);
}
